@@ -335,10 +335,14 @@ static void gtranslator_profile_dialog_init (GtranslatorProfileDialog *dlg)
 {
 	gboolean ret;
 	GtkWidget *error_widget;
+	gchar *root_objects [] = {
+		"profiles_dialog",
+		NULL
+	};
 	
 	dlg->priv = GTR_PROFILE_DIALOG_GET_PRIVATE (dlg);
 	
-	gtk_window_set_title (GTK_WINDOW (dlg), _("gtranslator Profile"));
+	gtk_window_set_title (GTK_WINDOW (dlg), _("Gtranslator Profile"));
 	gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg), TRUE);
@@ -346,8 +350,8 @@ static void gtranslator_profile_dialog_init (GtranslatorProfileDialog *dlg)
 	gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->vbox), 2);
 
-	ret = gtranslator_utils_get_glade_widgets(PKGDATADIR"/profile-dialog.glade",
-		"profiles_dialog",
+	ret = gtranslator_utils_get_ui_objects (PKGDATADIR"/profile-dialog.ui",
+		root_objects,
 		&error_widget,
 		"profiles_dialog", &dlg->priv->main_box,
 		"profile_entry", &dlg->priv->profile_name_entry,
@@ -364,8 +368,11 @@ static void gtranslator_profile_dialog_init (GtranslatorProfileDialog *dlg)
 	if(!ret)
 	{
 		gtk_widget_show(error_widget);
-		gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dlg)->vbox),
-					     error_widget);
+		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox),
+				    error_widget,
+				    TRUE,
+				    TRUE,
+				    0);
 		
 		return;
 	}
